#include "tao/IOR_Parser.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_IOR_Parser::~TAO_IOR_Parser ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
